summaryrefslogtreecommitdiff
path: root/gst/camerabin
diff options
context:
space:
mode:
authorLasse Laukkanen <ext-lasse.2.laukkanen@nokia.com>2009-02-25 10:45:19 +0200
committerStefan Kost <ensonic@users.sf.net>2009-02-25 10:45:19 +0200
commitc81bce2b213f5ea1305a15de6082d6f3ea6adb82 (patch)
tree96bb08d1a9424c4dfe7fb9135ec7a5ddb85bd590 /gst/camerabin
parent9d4c7e68abc7ed97dae8e54166be8462fe54cec1 (diff)
camerabin: unblock correct pad in reset, support fakesink as view finder
Diffstat (limited to 'gst/camerabin')
-rw-r--r--gst/camerabin/gstcamerabin.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gst/camerabin/gstcamerabin.c b/gst/camerabin/gstcamerabin.c
index e836b4b77..ee7191e9e 100644
--- a/gst/camerabin/gstcamerabin.c
+++ b/gst/camerabin/gstcamerabin.c
@@ -1670,9 +1670,9 @@ gst_camerabin_reset_to_view_finder (GstCameraBin * camera)
gst_pad_set_blocked_async (camera->srcpad_zoom_filter, FALSE,
(GstPadBlockCallback) image_pad_blocked, camera);
}
- /* Unblock, if dataflow to image bin is blocked due to waiting for eos */
- if (camera->pad_src_img && gst_pad_is_blocked (camera->pad_src_img)) {
- gst_pad_set_blocked_async (camera->pad_src_img, FALSE,
+ /* Unblock, if dataflow in videosrc is blocked due to waiting for eos */
+ if (camera->srcpad_videosrc && gst_pad_is_blocked (camera->srcpad_videosrc)) {
+ gst_pad_set_blocked_async (camera->srcpad_videosrc, FALSE,
(GstPadBlockCallback) image_pad_blocked, camera);
}
@@ -1916,7 +1916,7 @@ gst_camerabin_update_aspect_filter (GstCameraBin * camera, GstCaps * new_caps)
if (sink_pad) {
sink_caps = gst_pad_get_caps (sink_pad);
gst_object_unref (sink_pad);
- if (sink_caps) {
+ if (sink_caps && !gst_caps_is_any (sink_caps)) {
GST_DEBUG_OBJECT (camera, "sink element caps %" GST_PTR_FORMAT,
sink_caps);
/* Get maximum resolution that view finder sink accepts */